import"./jwt-decode.esm-C-pSId1x.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="58db978a-c586-4fbe-b4a2-361605c68e76",t._sentryDebugIdIdentifier="sentry-dbid-58db978a-c586-4fbe-b4a2-361605c68e76")}catch{}})();const s={HOMEPAGE:"https://abstra.io",DOCS:"https://abstra.io/docs",CLOUD:"https://cloud.abstra.io",GITHUB:"https://github.com/abstra-app/abstra-lib"},b=t=>{if(!t)return s.DOCS;const e=t.startsWith("/")?t.slice(1):t;return`${s.DOCS}/${e}`};export{s as A,b};
//# sourceMappingURL=constants-C4XOKD8R.js.map
