import{O as l}from"./workspaceStore-eHr1yftw.js";import{a as c,D as f,b as u,j as n,w as o,u as t,aj as _,ak as b,S as r,U as s,ae as i,e as p}from"./jwt-decode.esm-C-pSId1x.js";import"./userStore-Bi6uE2pG.js";import"./url-E85CsM4U.js";import"./colorHelpers-C04Sii74.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="89f4dccd-28b8-4317-bb69-f20b33ff296d",e._sentryDebugIdIdentifier="sentry-dbid-89f4dccd-28b8-4317-bb69-f20b33ff296d")}catch{}})();const D=c({__name:"OidcLoginCallback",setup(e){return f(async()=>{await new l().loginCallback()}),(a,d)=>(p(),u("div",null,[n(t(_),null,{default:o(()=>[r(s(t(i).translate("i18n_oidclogincallback_authenticated_title")),1)]),_:1}),n(t(b),null,{default:o(()=>[r(s(t(i).translate("i18n_oidclogincallback_close_window_message")),1)]),_:1})]))}});export{D as default};
//# sourceMappingURL=OidcLoginCallback-CUuMJPiU.js.map
