import{C as p,_ as n}from"./View.vue_vue_type_script_setup_true_lang-BP2puKMp.js";import{a as i,ac as s,p as a,e as m,u as c}from"./jwt-decode.esm-C-pSId1x.js";import"./router-BOY9wvA7.js";import"./ts.worker-FgSjKf5B.js";import"./fetch-DWTinINn.js";import"./record-DCCDzs6D.js";import"./SaveButton-BNgRecbu.js";import"./ExclamationCircleOutlined-DtZC_5vB.js";import"./CrudView-CSqLZQF3.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-AawO64rm.js";import"./constants-C4XOKD8R.js";import"./url-E85CsM4U.js";import"./PhDotsThreeVertical.vue-CihrGXh5.js";import"./index-SgEeyXlR.js";import"./asyncComputed-BFeGpB4N.js";import"./omniChatStore-BT3hCtq6.js";import"./uuid-EU9SeyOl.js";import"./PhCopySimple.vue-DRIvWMP-.js";import"./PhPencil.vue-Di-hdME0.js";import"./useCodebaseEvents-DgA37eVJ.js";import"./contracts.generated-L4G3AeVX.js";import"./index-8Hc8RFdj.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="d5568c8c-1d21-4381-b868-03578c6a487a",o._sentryDebugIdIdentifier="sentry-dbid-d5568c8c-1d21-4381-b868-03578c6a487a")}catch{}})();const A=i({__name:"EnvVars",setup(o){const t=s().params.projectId,e=new p(t);return(d,u)=>(m(),a(n,{"env-var-repository":c(e),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars-C-ATkQfT.js.map
