const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["assets/OidcLoginCallback-CUuMJPiU.js","assets/workspaceStore-eHr1yftw.js","assets/jwt-decode.esm-C-pSId1x.js","assets/jwt-decode-UwARlUKu.css","assets/userStore-Bi6uE2pG.js","assets/url-E85CsM4U.js","assets/colorHelpers-C04Sii74.js","assets/OidcLogoutCallback-nZlyL6LH.js","assets/Login-P8LnKcVj.js","assets/Login.vue_vue_type_script_setup_true_lang-Bno5TaUL.js","assets/CircularLoading-BoO6j31h.js","assets/CircularLoading-C7OKHy4X.css","assets/Logo-Dv3vQpmq.js","assets/Logo-D2kepPyK.css","assets/string-3_vhV9g4.js","assets/index-8Hc8RFdj.js","assets/Login-cMuNqCbG.css","assets/Login-C1k-SC0u.css","assets/Main-BavW0nNI.js","assets/PlayerNavbar-Kl-Xoemz.js","assets/metadata-BTVd7Yl8.js","assets/PhWebhooksLogo.vue-Czx9wDzz.js","assets/LoadingOutlined-vpSXtuA0.js","assets/PhSignOut.vue-lg5R-_Kw.js","assets/index-DFmQE1Z1.js","assets/PlayerNavbar-VlEtzX8f.css","assets/Main-DqPmGmnC.css","assets/Home-Cq3SiV6-.js","assets/Watermark-CGQ6d0wj.js","assets/constants-C4XOKD8R.js","assets/Watermark-DMbnzHiR.css","assets/PhArrowSquareOut.vue-Ml87HQlP.js","assets/index-Bt9KPalV.js","assets/Home-B6UGln4L.css","assets/Error-Bkp_ciN8.js","assets/AbstraLogo.vue_vue_type_script_setup_true_lang-BlPt8y5U.js","assets/Error-CIbhyrKS.css","assets/Form-BCMYhCZ2.js","assets/FormRunner-0JPk8JYZ.js","assets/Steps-BX1QCCG1.js","assets/index-S1VxHDRd.js","assets/Steps-DqO_G9S3.css","assets/FormRunner-61-wByB6.css","assets/redirect-CiJ1U3Fd.js","assets/asyncComputed-BFeGpB4N.js","assets/uuid-EU9SeyOl.js","assets/Form-BkLIfVj9.css"])))=>i.map(i=>d[i]);
import{af as i,ag as s,ah as t,ai as m}from"./jwt-decode.esm-C-pSId1x.js";import{a as u}from"./workspaceStore-eHr1yftw.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="c536dc6c-50e0-43bd-acdf-3ef67ff38d44",a._sentryDebugIdIdentifier="sentry-dbid-c536dc6c-50e0-43bd-acdf-3ef67ff38d44")}catch{}})();const b=async()=>{try{const a=await fetch("/_editor/api/workspace/version");return a.ok&&(await a.json()).version||"d5aed91a6ff5689059713c4d60c3fc2b782da90d"}catch(a){return console.error("Failed to fetch Abstra version:",a),"d5aed91a6ff5689059713c4d60c3fc2b782da90d"}},p=[{path:"/oidc-login-callback",name:"oidcLoginCallback",component:()=>t(()=>import("./OidcLoginCallback-CUuMJPiU.js"),__vite__mapDeps([0,1,2,3,4,5,6])),meta:{allowUnauthenticated:!0}},{path:"/oidc-logout-callback",name:"oidcLogoutCallback",component:()=>t(()=>import("./OidcLogoutCallback-nZlyL6LH.js"),__vite__mapDeps([7,1,2,3,4,5,6])),meta:{allowUnauthenticated:!0}},{path:"/login",name:"playerLogin",component:()=>t(()=>import("./Login-P8LnKcVj.js"),__vite__mapDeps([8,9,2,3,1,4,5,6,10,11,12,13,14,15,16,17])),meta:{allowUnauthenticated:!0}},{path:"/",name:"main",component:()=>t(()=>import("./Main-BavW0nNI.js"),__vite__mapDeps([18,19,4,2,3,1,5,6,20,21,22,23,24,25,26])),redirect:{name:"main"},children:[{path:"",name:"playerHome",component:()=>t(()=>import("./Home-Cq3SiV6-.js"),__vite__mapDeps([27,20,2,3,21,28,1,4,5,6,29,30,31,32,22,33])),meta:{title:"Home"}},{path:"_player/threads",redirect:{name:"playerThreads"}},{path:"error/:status",name:"error",component:()=>t(()=>import("./Error-Bkp_ciN8.js"),__vite__mapDeps([34,35,12,2,3,13,29,1,4,5,6,32,36])),meta:{allowUnauthenticated:!0}},{path:":path(.*)*",name:"form",component:()=>t(()=>import("./Form-BCMYhCZ2.js"),__vite__mapDeps([37,4,2,3,38,9,1,5,6,10,11,12,13,14,15,16,39,40,41,28,29,30,42,43,44,45,46])),meta:{hideLogin:!0}}]}],o=i({history:s("/"),routes:p,scrollBehavior(a){if(a.hash)return{el:a.hash}}}),l=a=>async(e,r)=>{if(m(e,r),e.meta.allowUnauthenticated)return;const n=await u(e.path),{redirect:c,...d}=e.query;switch(n.status){case"ALLOWED":break;case"UNAUTHORIZED":await a.push({name:"playerLogin",query:{...d,redirect:c||e.path},params:e.params});break;case"NOT_FOUND":await a.push({name:"error",params:{status:"404"}});break;default:await a.push({name:"error",params:{status:"403"}})}};o.beforeEach(l(o));export{p as a,l as b,b as g,o as r};
//# sourceMappingURL=router-Dv6zFnY2.js.map
